Stan Math Library: stan/math/prim/scal/meta/scalar_type_pre.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
scalar_type_pre.hpp File Reference
`#include <stan/math/prim/scal/meta/is_vector.hpp>`
`#include <stan/math/prim/scal/meta/value_type.hpp>`

Go to the source code of this file.

## Classes
struct | stan::scalar_type_pre< T >
| Metaprogram structure to determine the type of first container of the base scalar type of a template argument. More...

## Namespaces
| stan

[ Stan Home Page ] © 2011–2016, Stan Development Team.